@@ -1,5 +1,6 @@
 """Data for the Natural Language Processing module of the PPP."""
 
 from .nounification import nounificationExceptions
+from .exceptions import GrammaticalError
 
-__all__ = ['nounificationExceptions']
+__all__ = ['nounificationExceptions','GrammaticalError']
