@@ -2,7 +2,7 @@ import sys
 from .preprocessingMerge import Word
 from .preprocessing import DependenciesTree
 from .data.exceptions import QuestionWordError
-from .data.questionWord import closeQuestionWord, openQuestionWord, questionAdd, questionWIs, questionType
+from .data.questionWord import closeQuestionWord, openQuestionWord, questionAdd, questionWIs, questionType, questionExcept
 
 def removeWord(t,word):
     """
@@ -38,7 +38,12 @@ def identifyQuestionWord(t):
     start = [None,None]
     firstWords(t,start)
     if not start[0]:
-        raise QuestionWordError(t,"do not understand")
+        start[0] = Word(t.text.split(' ', 1)[0],1)
+    if not start[1]:
+        try:
+            start[1] = Word(t.text.split(' ', 1)[1],2)
+        except IndexError:
+            pass
     if start[1] and start[0].word.lower() + ' ' + start[1].word.lower() in openQuestionWord:
         removeWord(t,start[0])
         removeWord(t,start[1])
@@ -60,7 +65,13 @@ def processQuestionType(t,w,typeMap=questionType):
     except KeyError:
         pass
 
-def processQuestionInfo(t,w,addMap=questionAdd,wisMap=questionWIs):
+def checkList(s,l):
+    for n in l:
+        if s.find(n) != -1:
+            return False
+    return True
+
+def processQuestionInfo(t,w,excMap=questionExcept,addMap=questionAdd,wisMap=questionWIs):
     """
         Add info to the first sons of ROOT that are not connectors (ie index < 1000) depending on:
             - the question word
@@ -72,7 +83,7 @@ def processQuestionInfo(t,w,addMap=questionAdd,wisMap=questionWIs):
                 processQuestionInfo(n,w)
         elif t.getWords() == 'identity':
             t.wordList[0].word = wisMap[w] # contains 'identity', replace it according to the question word
-        elif t.getWords().find(addMap[w]) == -1: # doesn't contain 'identity' and doesn't contain the word associated to w in addMap
+        elif checkList(t.getWords(),excMap[w]): # doesn't contain 'identity' and doesn't contain the word associated to w in excMap
             t.wordList.append(Word(addMap[w],1001))
     except KeyError:
         pass
